Metadata

Struct Metadata 

pub struct Metadata {
Show 27 fields pub metadata_version: String, pub name: String, pub version: String, pub platforms: Vec<String>, pub supported_platforms: Vec<String>, pub summary: Option<String>, pub description: Option<String>, pub keywords: Option<String>, pub home_page: Option<String>, pub download_url: Option<String>, pub author: Option<String>, pub author_email: Option<String>, pub license: Option<String>, pub license_expression: Option<String>, pub license_files: Vec<String>, pub classifiers: Vec<String>, pub requires_dist: Vec<String>, pub provides_dist: Vec<String>, pub obsoletes_dist: Vec<String>, pub maintainer: Option<String>, pub maintainer_email: Option<String>, pub requires_python: Option<String>, pub requires_external: Vec<String>, pub project_urls: Vec<String>, pub provides_extras: Vec<String>, pub description_content_type: Option<String>, pub dynamic: Vec<String>,
}
Python package metadata

Fields

metadata_version: String

Version of the file format; legal values are 1.0, 1.1, 1.2, 2.1 and 2.2.

name: String

The name of the distribution.

version: String

A string containing the distribution’s version number.

platforms: Vec<String>

A Platform specification describing an operating system supported by the distribution which is not listed in the “Operating System” Trove classifiers.

supported_platforms: Vec<String>

Binary distributions containing a PKG-INFO file will use the Supported-Platform field in their metadata to specify the OS and CPU for which the binary distribution was compiled.

summary: Option<String>

A one-line summary of what the distribution does.

description: Option<String>

A longer description of the distribution that can run to several paragraphs.

keywords: Option<String>

A list of additional keywords, separated by commas, to be used to assist searching for the distribution in a larger catalog.

home_page: Option<String>

A string containing the URL for the distribution’s home page.

download_url: Option<String>

A string containing the URL from which this version of the distribution can be downloaded.

author: Option<String>

A string containing the author’s name at a minimum; additional contact information may be provided.

author_email: Option<String>

A string containing the author’s e-mail address. It can contain a name and e-mail address in the legal forms for a RFC-822 From: header.

license: Option<String>

Text indicating the license covering the distribution where the license is not a selection from the License Trove classifiers or an SPDX license expression.

license_expression: Option<String>

An SPDX expression indicating the license covering the distribution.

license_files: Vec<String>

Paths to files containing the text of the licenses covering the distribution.

classifiers: Vec<String>

Each entry is a string giving a single classification value for the distribution.

requires_dist: Vec<String>

Each entry contains a string naming some other distutils project required by this distribution.

provides_dist: Vec<String>

Each entry contains a string naming a Distutils project which is contained within this distribution.

obsoletes_dist: Vec<String>

Each entry contains a string describing a distutils project’s distribution which this distribution renders obsolete, meaning that the two projects should not be installed at the same time.

maintainer: Option<String>

A string containing the maintainer’s name at a minimum; additional contact information may be provided.

Note that this field is intended for use when a project is being maintained by someone other than the original author: it should be omitted if it is identical to author.

maintainer_email: Option<String>

A string containing the maintainer’s e-mail address. It can contain a name and e-mail address in the legal forms for a RFC-822 From: header.

Note that this field is intended for use when a project is being maintained by someone other than the original author: it should be omitted if it is identical to author_email.

requires_python: Option<String>

This field specifies the Python version(s) that the distribution is guaranteed to be compatible with.

requires_external: Vec<String>

Each entry contains a string describing some dependency in the system that the distribution is to be used.

project_urls: Vec<String>

A string containing a browsable URL for the project and a label for it, separated by a comma.

provides_extras: Vec<String>

A string containing the name of an optional feature. Must be a valid Python identifier. May be used to make a dependency conditional on whether the optional feature has been requested.

description_content_type: Option<String>

A string stating the markup syntax (if any) used in the distribution’s description, so that tools can intelligently render the description.

dynamic: Vec<String>

A string containing the name of another core metadata field.

Implementations

Source

impl Metadata

pub fn parse(content: &[u8]) -> Result<Self, Error>

Parse distribution metadata from metadata bytes